LogEvent class final
Main model, which collect, hold and transfer data between threads.
Serialize and deserialize data.
Constructors
- LogEvent({required SourceName sourceName, required String? isolateDebugName, required LogLevel level, required String message, required DateTime time, StackTrace? stackTrace})
-
const
-
LogEvent.fromMap(Map<
String, Object> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isolateDebugName → String?
-
Optional
sourcelabel, if same code executed in different isolates.final - level → LogLevel
-
final
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceName → String
-
final
- stackTrace → StackTrace?
-
final
- time → DateTime
-
Event's creation time.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited